@@ -1,21 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "activitiesmanager.h"
 #include "accountactivities.h"
-
-#include <PlasmaActivities/Consumer>
+#include "transportactivities.h"
 
 ActivitiesManager::ActivitiesManager(QObject *parent)
     : PimCommonActivities::ActivitiesBaseManager{parent}
-    , mActivitiesConsumer(new KActivities::Consumer(this))
     , mAccountActivities(new AccountActivities(this))
+    , mTransportActivities(new TransportActivities(this))
 {
     connect(this, &ActivitiesManager::activitiesChanged, this, [this]() {
         Q_EMIT mAccountActivities->activitiesChanged();
+        Q_EMIT mTransportActivities->activitiesChanged();
     });
 }
 
@@ -27,22 +27,14 @@ ActivitiesManager *ActivitiesManager::self()
     return &s_self;
 }
 
-bool ActivitiesManager::enabled() const
-{
-    return mEnabled;
-}
-
-void ActivitiesManager::setEnabled(bool newEnabled)
-{
-    if (mEnabled != newEnabled) {
-        mEnabled = newEnabled;
-        Q_EMIT activitiesChanged();
-    }
-}
-
 AccountActivities *ActivitiesManager::accountActivities() const
 {
     return mAccountActivities;
 }
 
+TransportActivities *ActivitiesManager::transportActivities() const
+{
+    return mTransportActivities;
+}
+
 #include "moc_activitiesmanager.cpp"
