@@ -4,7 +4,7 @@
   SPDX-FileCopyrightText: 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2009 Sebastian Sauer <sebsauer@kdab.net>
-  SPDX-FileCopyrightText: 2010-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2025 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -744,16 +744,32 @@ void AkonadiCollectionView::deleteCalendar()
     const QString displayname = index.model()->data(index, Qt::DisplayRole).toString();
     Q_ASSERT(!displayname.isEmpty());
 
+    bool isTopLevel = collection.parentCollection() == Akonadi::Collection::root();
+
+    QString yesNoMessage;
+    if (isTopLevel) {
+        yesNoMessage = xi18nc("@info",
+                              "Do you really want to delete the <filename>%1</filename> calendar?"
+                              "<para><note>The calendar data will not be deleted, nor will the calendar "
+                              "be removed from its remote resource.</note></para>"
+                              "The <filename>%1</filename> calendar can be added again at any time.",
+                              displayname);
+    } else {
+        yesNoMessage = xi18nc("@info",
+                              "Do you really want to delete the <filename>%1</filename> calendar?"
+                              "<para><warning>This cannot be undone.  "
+                              "Please consider carefully before pressing the %2 button.</warning></para>",
+                              displayname,
+                              KStandardGuiItem::standardItem(KStandardGuiItem::Delete));
+    }
     if (KMessageBox::warningContinueCancel(this,
-                                           i18nc("@info", "Do you really want to delete calendar %1?", displayname),
+                                           yesNoMessage,
                                            i18nc("@title:window", "Delete Calendar"),
                                            KStandardGuiItem::del(),
                                            KStandardGuiItem::cancel(),
                                            QString(),
                                            KMessageBox::Dangerous)
         == KMessageBox::Continue) {
-        bool isTopLevel = collection.parentCollection() == Akonadi::Collection::root();
-
         mNotSendAddRemoveSignal = true;
         mWasDefaultCalendar = KOHelper::isStandardCalendar(collection.id());
 
@@ -863,7 +879,7 @@ void AkonadiCollectionView::onAction(const QModelIndex &index, int a)
 {
     const auto action = static_cast<StyledCalendarDelegate::Action>(a);
     switch (action) {
-    case StyledCalendarDelegate::Quickview: {
+    case StyledCalendarDelegate::Action::Quickview: {
         const auto collection = Akonadi::CollectionUtils::fromIndex(index);
         const auto title = Akonadi::CalendarUtils::displayName(entityTreeModel(), collection);
         auto quickview = new Quickview(mCalendarView->calendarForCollection(collection), title);
@@ -871,7 +887,7 @@ void AkonadiCollectionView::onAction(const QModelIndex &index, int a)
         quickview->show();
         break;
     }
-    case StyledCalendarDelegate::Total:
+    case StyledCalendarDelegate::Action::Total:
         // TODO: anything to implement here?
         break;
     }
